From 3bd663d454c05d38b629a9807b89bcb332ccae1a Mon Sep 17 00:00:00 2001
From: Andres Freund <andres@anarazel.de>
Date: Tue, 27 Sep 2022 11:55:00 -0700
Subject: [PATCH v1 1/6] meson: windows: Normalize slashes in prefix

This fixes a build issue on windows, when the prefix is set to a path with
forward slashes. Windows python defaults to a path with a backslash, but mingw
ucrt python defaults to a forward slash. This in turn lead to a wrong PATH set
during tests, causing tests to fail.

Reported-by: Melih Mutlu <m.melihmutlu@gmail.com>
Discussion: http://postgr.es/m/20220928022724.erzuk5v4ai4b53do@awork3.anarazel.de
---
 meson.build | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/meson.build b/meson.build
index 38b2c3aae2e..02c086c04e7 100644
--- a/meson.build
+++ b/meson.build
@@ -2733,15 +2733,15 @@ endif
 
 prefix = get_option('prefix')
 
-test_prefix = prefix
+test_prefix = fs.as_posix(prefix)
 
 if fs.is_absolute(get_option('prefix'))
   if host_system == 'windows'
-    if prefix.split(':\\').length() == 1
+    if prefix.split(':/').length() == 1
       # just a drive
       test_prefix = ''
     else
-      test_prefix = prefix.split(':\\')[1]
+      test_prefix = prefix.split(':/')[1]
     endif
   else
     assert(prefix.startswith('/'))
-- 
2.37.3.542.gdd3f6c4cae

